==> ckeditor_4.5.7+dfsg.orig.tar.xz: ckeditor-dev-4.5.7/plugins/link/lang/el.js <==
/*
Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'link', 'el', {
	acccessKey: 'Συντόμευση',
	advanced: 'Για Προχωρημένους',
	advisoryContentType: 'Ενδεικτικός Τύπος Περιεχομένου',
	advisoryTitle: 'Ενδεικτικός Τίτλος',
	anchor: {
		toolbar: 'Εισαγωγή/επεξεργασία Άγκυρας',
		menu: 'Ιδιότητες άγκυρας',
		title: 'Ιδιότητες άγκυρας',
		name: 'Όνομα άγκυρας',
		errorName: 'Παρακαλούμε εισάγετε όνομα άγκυρας',
		remove: 'Αφαίρεση Άγκυρας'
	},
	anchorId: 'Βάσει του Element Id',
	anchorName: 'Βάσει του Ονόματος Άγκυρας',
	charset: 'Κωδικοποίηση Χαρακτήρων Προσαρτημένης Πηγής',
	cssClasses: 'Κλάσεις Φύλλων Στυλ',
	emailAddress: 'Διεύθυνση E-mail',
	emailBody: 'Κείμενο Μηνύματος',
	emailSubject: 'Θέμα Μηνύματος',
	id: 'Id',
	info: 'Πληροφορίες Συνδέσμου',
	langCode: 'Κατεύθυνση Κειμένου',
	langDir: 'Κατεύθυνση Κειμένου',
	langDirLTR: 'Αριστερά προς Δεξιά (LTR)',
	langDirRTL: 'Δεξιά προς Αριστερά (RTL)',
	menu: 'Επεξεργασία Συνδέσμου',
	name: 'Όνομα',
	noAnchors: '(Δεν υπάρχουν άγκυρες στο κείμενο)',
	noEmail: 'Εισάγετε τη διεύθυνση ηλεκτρονικού ταχυδρομείου',
	noUrl: 'Εισάγετε την τοποθεσία (URL) του συνδέσμου',
	other: '<άλλο>',
	popupDependent: 'Εξαρτημένο (Netscape)',
	popupFeatures: 'Επιλογές Αναδυόμενου Παραθύρου',
	popupFullScreen: 'Πλήρης Οθόνη (IE)',
	popupLeft: 'Θέση Αριστερά',
	popupLocationBar: 'Γραμμή Τοποθεσίας',
	popupMenuBar: 'Γραμμή Επιλογών',
	popupResizable: 'Προσαρμοζόμενο Μέγεθος',
	popupScrollBars: 'Μπάρες Κύλισης',
	popupStatusBar: 'Γραμμή Κατάστασης',
	popupToolbar: 'Εργαλειοθήκη',
	popupTop: 'Θέση Πάνω',
	rel: 'Σχέση',
	selectAnchor: 'Επιλέξτε μια Άγκυρα',
	styles: 'Μορφή',
	tabIndex: 'Σειρά Μεταπήδησης',
	target: 'Παράθυρο Προορισμού',
	targetFrame: '<πλαίσιο>',
	targetFrameName: 'Όνομα Πλαισίου Προορισμού',
	targetPopup: '<αναδυόμενο παράθυρο>',
	targetPopupName: 'Όνομα Αναδυόμενου Παραθύρου',
	title: 'Σύνδεσμος',
	toAnchor: 'Άγκυρα σε αυτήν τη σελίδα',
	toEmail: 'E-Mail',
	toUrl: 'URL',
	toolbar: 'Σύνδεσμος',
	type: 'Τύπος Συνδέσμου',
	unlink: 'Αφαίρεση Συνδέσμου',
	upload: 'Αποστολή'
} );

==> ckeditor_4.11.1+dfsg.orig.tar.xz: ckeditor-dev-4.11.1/plugins/link/lang/el.js <==
﻿/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'el', {
	acccessKey: 'Συντόμευση',
	advanced: 'Για Προχωρημένους',
	advisoryContentType: 'Ενδεικτικός Τύπος Περιεχομένου',
	advisoryTitle: 'Ενδεικτικός Τίτλος',
	anchor: {
		toolbar: 'Εισαγωγή/επεξεργασία Άγκυρας',
		menu: 'Ιδιότητες άγκυρας',
		title: 'Ιδιότητες άγκυρας',
		name: 'Όνομα άγκυρας',
		errorName: 'Παρακαλούμε εισάγετε όνομα άγκυρας',
		remove: 'Αφαίρεση Άγκυρας'
	},
	anchorId: 'Βάσει του Element Id',
	anchorName: 'Βάσει του Ονόματος Άγκυρας',
	charset: 'Κωδικοποίηση Χαρακτήρων Προσαρτημένης Πηγής',
	cssClasses: 'Κλάσεις Φύλλων Στυλ',
	download: 'Force Download', // MISSING
	displayText: 'Display Text', // MISSING
	emailAddress: 'Διεύθυνση E-mail',
	emailBody: 'Κείμενο Μηνύματος',
	emailSubject: 'Θέμα Μηνύματος',
	id: 'Id',
	info: 'Πληροφορίες Συνδέσμου',
	langCode: 'Κατεύθυνση Κειμένου',
	langDir: 'Κατεύθυνση Κειμένου',
	langDirLTR: 'Αριστερά προς Δεξιά (LTR)',
	langDirRTL: 'Δεξιά προς Αριστερά (RTL)',
	menu: 'Επεξεργασία Συνδέσμου',
	name: 'Όνομα',
	noAnchors: '(Δεν υπάρχουν άγκυρες στο κείμενο)',
	noEmail: 'Εισάγετε τη διεύθυνση ηλεκτρονικού ταχυδρομείου',
	noUrl: 'Εισάγετε την τοποθεσία (URL) του συνδέσμου',
	noTel: 'Please type the phone number', // MISSING
	other: '<άλλο>',
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'Εξαρτημένο (Netscape)',
	popupFeatures: 'Επιλογές Αναδυόμενου Παραθύρου',
	popupFullScreen: 'Πλήρης Οθόνη (IE)',
	popupLeft: 'Θέση Αριστερά',
	popupLocationBar: 'Γραμμή Τοποθεσίας',
	popupMenuBar: 'Γραμμή Επιλογών',
	popupResizable: 'Προσαρμοζόμενο Μέγεθος',
	popupScrollBars: 'Μπάρες Κύλισης',
	popupStatusBar: 'Γραμμή Κατάστασης',
	popupToolbar: 'Εργαλειοθήκη',
	popupTop: 'Θέση Πάνω',
	rel: 'Σχέση',
	selectAnchor: 'Επιλέξτε μια Άγκυρα',
	styles: 'Μορφή',
	tabIndex: 'Σειρά Μεταπήδησης',
	target: 'Παράθυρο Προορισμού',
	targetFrame: '<πλαίσιο>',
	targetFrameName: 'Όνομα Πλαισίου Προορισμού',
	targetPopup: '<αναδυόμενο παράθυρο>',
	targetPopupName: 'Όνομα Αναδυόμενου Παραθύρου',
	title: 'Σύνδεσμος',
	toAnchor: 'Άγκυρα σε αυτήν τη σελίδα',
	toEmail: 'E-Mail',
	toUrl: 'URL',
	toPhone: 'Phone', // MISSING
	toolbar: 'Σύνδεσμος',
	type: 'Τύπος Συνδέσμου',
	unlink: 'Αφαίρεση Συνδέσμου',
	upload: 'Αποστολή'
} );
